@@ -12,7 +12,7 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-12-14 13:31:25 +0800 (??, 14 ??? 2018) $
+# $Date: 2018-12-14 14:31:25 +0900 (週五, 14 十二月 2018) $
 # $Revision: 11314 $
 
 import logging
@@ -82,7 +82,7 @@ def attachSettings(settingsLocals, backends, preferred, config):
         },
         'MIDDLEWARE_CLASSES': settingsLocals.get('MIDDLEWARE_CLASSES', ()) + [
             ('raven.contrib.django.raven_compat.middleware.'
-             'SentryResponseErrorIdMiddleware'),
+             'SentryResponseErrorIdMiddleware',),
         ],
     })
 
